@@ -91,7 +91,7 @@ KOPrefsDialogTime::KOPrefsDialogTime(QObject *parent, const KPluginMetaData &dat
         }
         regionsMap.emplace_back(label, regionCode);
     }
-    std::sort(regionsMap.begin(), regionsMap.end(), [](const auto &lhs, const auto &rhs) {
+    std::ranges::sort(regionsMap, [](const auto &lhs, const auto &rhs) {
         return lhs.first < rhs.first;
     });
 
@@ -108,7 +108,7 @@ KOPrefsDialogTime::KOPrefsDialogTime(QObject *parent, const KPluginMetaData &dat
         mHolidayCheckCombo->setItemCheckState(mHolidayCheckCombo->findData(regionStr), Qt::Checked);
     }
 
-    auto workingHoursGroupBox = new QGroupBox(i18nc("@title:group", "Working Period"), regionalPage);
+    auto workingHoursGroupBox = new QGroupBox(i18nc("@title:group", "Weekly Schedule"), regionalPage);
     regionalLayout->addWidget(workingHoursGroupBox, 2, 0);
 
     QBoxLayout *workingHoursLayout = new QVBoxLayout(workingHoursGroupBox);
@@ -117,17 +117,19 @@ KOPrefsDialogTime::KOPrefsDialogTime(QObject *parent, const KPluginMetaData &dat
     workingHoursLayout->addLayout(workDaysLayout);
 
     // Respect start of week setting
-    int weekStart = QLocale().firstDayOfWeek();
+    const int weekStart = QLocale().firstDayOfWeek();
     for (int i = 0; i < 7; ++i) {
-        QString weekDayName = QLocale().dayName((i + weekStart + 6) % 7 + 1, QLocale::ShortFormat);
-        int index = (i + weekStart + 6) % 7;
+        const QString weekDayName = QLocale().dayName((i + weekStart + 6) % 7 + 1, QLocale::ShortFormat);
+        const QString weekDayNameLong = QLocale().dayName((i + weekStart + 6) % 7 + 1, QLocale::LongFormat);
+        const int index = (i + weekStart + 6) % 7;
         mWorkDays[index] = new QCheckBox(weekDayName);
+        mWorkDays[index]->setToolTip(i18nc("@info:tooltip", "Include %1 as part of your weekly schedule", weekDayNameLong));
         mWorkDays[index]->setWhatsThis(i18nc("@info:whatsthis",
-                                             "Check this box to make KOrganizer mark the "
-                                             "working hours for this day of the week. "
-                                             "If this is a work day for you, check "
-                                             "this box, or the working hours will not be "
-                                             "marked with color."));
+                                             "Check this box to consider %1 a part of your regular weekly schedule. "
+                                             "Any %1 daily hours will be shown with different colors than times outside your regular schedule. "
+                                             "Check this box if %1 is included as part of your regular weekly schedule (even if you don't work). "
+                                             "Typically, weekend days should be unchecked.",
+                                             weekDayNameLong));
         connect(mWorkDays[index], &QCheckBox::checkStateChanged, this, &Korganizer::KPrefsModule::slotWidChanged);
 
         workDaysLayout->addWidget(mWorkDays[index]);
@@ -162,6 +164,9 @@ KOPrefsDialogTime::KOPrefsDialogTime(QObject *parent, const KPluginMetaData &dat
     workEndLayout->addWidget(workEnd->timeEdit());
 
     Korganizer::KPrefsWidBool *excludeHolidays = addWidBool(CalendarSupport::KCalPrefs::instance()->excludeHolidaysItem());
+    excludeHolidays->checkBox()->setToolTip(i18nc("@info:tooltip", "Highlight holidays differently from your regular schedule"));
+    excludeHolidays->checkBox()->setWhatsThis(
+        i18nc("@info:whatsthis", "Check this box to highlight holidays differently than days included with your regular schedule."));
 
     workingHoursLayout->addWidget(excludeHolidays->checkBox());
 
@@ -216,7 +221,7 @@ KOPrefsDialogTime::KOPrefsDialogTime(QObject *parent, const KPluginMetaData &dat
             QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("sound/") + QLatin1StringView("KDE-Sys-Warning.ogg"));
         CalendarSupport::KCalPrefs::instance()->audioFilePathItem()->setValue(defAudioFile);
     }
-    const QString filter = i18n("Audio Files (*.ogg *.wav *.mp3 *.wma *.flac *.aiff *.raw *.au *.ra)");
+    const QString filter = i18nc("@info/plain", "Audio Files (*.ogg *.wav *.mp3 *.wma *.flac *.aiff *.raw *.au *.ra)");
     KUrlRequester *rq = addWidPath(CalendarSupport::KCalPrefs::instance()->audioFilePathItem(), nullptr, filter)->urlRequester();
     rq->setEnabled(cb->isChecked());
 
@@ -248,7 +253,7 @@ void KOPrefsDialogTime::usrWriteConfig()
     QStringList HolidayRegions;
     const auto checkedItems = mHolidayCheckCombo->checkedItems();
     for (const QString &str : checkedItems) {
-        int index = mHolidayCheckCombo->findText(str);
+        const int index = mHolidayCheckCombo->findText(str);
         if (index >= 0) {
             HolidayRegions.append(mHolidayCheckCombo->itemData(index).toString());
         }
@@ -270,22 +275,4 @@ void KOPrefsDialogTime::usrWriteConfig()
     setNeedsSave(false);
 }
 
-void KOPrefsDialogTime::setCombo(KComboBox *combo, const QString &text, const QStringList *tags)
-{
-    if (tags) {
-        int i = tags->indexOf(text);
-        if (i > 0) {
-            combo->setCurrentIndex(i);
-        }
-    } else {
-        const int numberOfElements{combo->count()};
-        for (int i = 0; i < numberOfElements; ++i) {
-            if (combo->itemText(i) == text) {
-                combo->setCurrentIndex(i);
-                break;
-            }
-        }
-    }
-}
-
 #include "koprefsdialogtime.moc"
